==> spip_3.2.11.orig.tar.xz: plugins-dist/revisions/lang/revisions_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Все зміни',

	// D
	'diff_para_ajoute' => 'Абзац додано',
	'diff_para_deplace' => 'Абзац переміщено',
	'diff_para_supprime' => 'Пункт видалений',
	'diff_texte_ajoute' => 'Доданий текст',
	'diff_texte_deplace' => 'Переміщений текст',
	'diff_texte_supprime' => 'Видалений текст',
	'differences_versions' => 'Відмінності між версією №@id_version@ и №@id_diff@',

	// I
	'icone_restaurer_version' => 'Відновити версію №@version@',
	'icone_suivi_revisions' => 'Відслідковування змін',
	'info_1_revision' => '1 версія',
	'info_aucune_revision' => 'У цього матеріалу нема інших версій',
	'info_historique' => 'Зміни в:',
	'info_historique_lien' => 'Історія змін',
	'info_historique_titre' => 'Історія змін',
	'info_nb_revisions' => '@nb@ змін',

	// L
	'label_choisir_id_version' => 'Порівняти з попереднєю версією',
	'label_config_revisions_objets' => 'Зберігати історію змін для:',

	// M
	'message_valider_recuperer_version' => 'Заповніть форму, щоб відновити до цієї версії.',

	// O
	'objet_editorial' => 'об´єкт',

	// P
	'plugin_update' => 'Поновити плагін „Révisions” до версії @version@.',

	// T
	'titre_form_revisions_objets' => 'Вести історію змін',
	'titre_restaurer_version' => 'Повернутися до варіанту',
	'titre_revisions' => 'Історія змін',

	// V
	'version_deplace_rubrique' => 'Перемістити з <b>„@from@”</b> в <b>„@to@”</b>.',
	'version_initiale' => 'Початкова версія',
	'voir_differences' => 'Продивитися відмінності',
	'voir_mes_revisions' => 'Мої зміни',
	'voir_revisions' => 'Історія змін (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'Усі зміни'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=uk
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Все зміни',

	// D
	'diff_para_ajoute' => 'Абзац додано',
	'diff_para_deplace' => 'Абзац переміщено',
	'diff_para_supprime' => 'Пункт видалений',
	'diff_texte_ajoute' => 'Доданий текст',
	'diff_texte_deplace' => 'Переміщений текст',
	'diff_texte_supprime' => 'Видалений текст',
	'differences_versions' => 'Відмінності між версією №@id_version@ и №@id_diff@',

	// I
	'icone_restaurer_version' => 'Відновити версію №@version@',
	'icone_suivi_revisions' => 'Відслідковування змін',
	'info_1_revision' => '1 версія',
	'info_aucune_revision' => 'У цього матеріалу нема інших версій',
	'info_historique' => 'Зміни в:',
	'info_historique_lien' => 'Історія змін',
	'info_historique_titre' => 'Історія змін',
	'info_nb_revisions' => '@nb@ змін',

	// L
	'label_choisir_id_version' => 'Порівняти з попереднєю версією',
	'label_config_revisions_objets' => 'Зберігати історію змін для:',

	// M
	'message_valider_recuperer_version' => 'Заповніть форму, щоб відновити до цієї версії.',

	// O
	'objet_editorial' => 'об´єкт',

	// P
	'plugin_update' => 'Поновити плагін „Révisions” до версії @version@.',

	// T
	'titre_form_revisions_objets' => 'Вести історію змін',
	'titre_restaurer_version' => 'Повернутися до варіанту',
	'titre_revisions' => 'Історія змін',

	// V
	'version_deplace_rubrique' => 'Перемістити з <b>„@from@”</b> в <b>„@to@”</b>.',
	'version_initiale' => 'Початкова версія',
	'voir_differences' => 'Продивитися відмінності',
	'voir_mes_revisions' => 'Мої зміни',
	'voir_revisions' => 'Історія змін (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'Усі зміни',
];
